package com.ruoyi.care.mapper;

import java.util.List;
import com.ruoyi.care.domain.CareScores;

/**
 * 业务评分Mapper接口
 * 
 * @author qy
 * @date 2024-11-26
 */
public interface CareScoresMapper 
{
    /**
     * 查询业务评分
     * 
     * @param scoreId 业务评分主键
     * @return 业务评分
     */
    public CareScores selectCareScoresByScoreId(Long scoreId);

    /**
     * 查询业务评分列表
     * 
     * @param careScores 业务评分
     * @return 业务评分集合
     */
    public List<CareScores> selectCareScoresList(CareScores careScores);

    /**
     * 新增业务评分
     * 
     * @param careScores 业务评分
     * @return 结果
     */
    public int insertCareScores(CareScores careScores);

    /**
     * 修改业务评分
     * 
     * @param careScores 业务评分
     * @return 结果
     */
    public int updateCareScores(CareScores careScores);

    /**
     * 删除业务评分
     * 
     * @param scoreId 业务评分主键
     * @return 结果
     */
    public int deleteCareScoresByScoreId(Long scoreId);

    /**
     * 批量删除业务评分
     * 
     * @param scoreIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteCareScoresByScoreIds(Long[] scoreIds);
}
